==> live-usb-maker-gui-antix_0.1.10.tar.xz: live-usb-maker-gui-antix/translations/live-usb-maker-gui-antix_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleziona il dispositivo USB di destinazione&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleziona un file ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <location filename="mainwindow.cpp" line="446"/>
        <location filename="mainwindow.cpp" line="464"/>
        <source>Select ISO</source>
        <translation>Seleziona un file ISO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>Refresh drive list</source>
        <translation>Aggiorna l&apos;elenco delle unità</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="112"/>
        <location filename="mainwindow.cpp" line="393"/>
        <location filename="mainwindow.cpp" line="399"/>
        <source>Show advanced options</source>
        <translation>Mostra le opzioni avanzate</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="130"/>
        <source>Advanced Options</source>
        <translation>Opzioni avanzate</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="139"/>
        <source>Verbosity (less to more):</source>
        <translation>Dettagli (da meno a più):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Dimensione della partizione ESP (UEFI):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="222"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Crea il filesystem ext4, anche se ne esiste già uno</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="229"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Salva la directory boot quando si aggiorna una Live USB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="236"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Usa il partizionamento GPT invece di quello MS-DOS</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <source>GPT partitioning</source>
        <translation>Partizionamento GPT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="246"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Aggiorna (solo una Live USB esistente)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="253"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Non sostituire i file di syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="256"/>
        <source>Keep syslinux files</source>
        <translation>Mantieni i file di syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="263"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignora il controllo dispositivi rimovibili/USB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="270"/>
        <source>Temporarily disable automounting</source>
        <translation>Disabilita temporaneamente il montaggio automatico</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="280"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Imposta il flag del disco come pmbr_boot (non effettua il boot tramite UEFI)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="293"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="308"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Non eseguire i comandi che hanno effetto sul dispositivo USB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="311"/>
        <source>Dry run (no change to system)</source>
        <translation>Fai una prova (nessuna modifica al sistema)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="318"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Clona da una Live USB montata, o un file ISO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="321"/>
        <source>Clone an existing live system</source>
        <translation>Clona un sistema &apos;live&apos; esistente</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="328"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Imposta il boot da una partizione crittografata. Verrà richiesta la passphrase al primo avvio</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="331"/>
        <source>Encrypt</source>
        <translation>Crittografa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="338"/>
        <source>Clone running live system</source>
        <translation>Clona il sistema &apos;live&apos; in esecuzione</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="345"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Sola lettura, non può essere utilizzato con la persistenza</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Copy image to USB (dd)</source>
        <translation>Copia immagine nella USB (dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>Percent of USB-device to use:</source>
        <translation>Percentuale del dispositivo USB da usare:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>Label ext partition:</source>
        <translation>Etichetta della partizione ext:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="442"/>
        <source>For distros other than antiX/MX use &quot;Copy image to USB (dd)&quot; only.</source>
        <translation>Per le distribuzioni che non sono antiX/MX, usa solamente &apos;Copia immagine nella USB (dd)&apos;.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="499"/>
        <source>Quit application</source>
        <translation>Esci dall&apos;applicazione</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="502"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="542"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="545"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="553"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="569"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="628"/>
        <source>Next</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="655"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="658"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="666"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="72"/>
        <location filename="mainwindow.cpp" line="239"/>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Failure</source>
        <translation>Operazione non riuscita</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="72"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Sorgente e destinazione sono sullo stesso dispositivo, seleziona di nuovo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="94"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Scrittura di %1 su /dev/%2, utilizzando il comando &apos;dd&apos;,

Attendi fino al completamento del processo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <source>Success</source>
        <translation>Operazione riuscita</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <source>LiveUSB creation successful!</source>
        <translation>La creazione della Live USB ha avuto successo!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="239"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Riscontrato un errore durante il processo di creazione della Live USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <source>Please select a USB device to write to</source>
        <translation>Seleziona un dispositivo USB per la scrittura</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="288"/>
        <location filename="mainwindow.cpp" line="458"/>
        <source>clone</source>
        <translation>clona</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="328"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="329"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programma per la creazione di una Live USB da un file ISO, un&apos;altra Live USB o di un sistema &apos;live&apos; in esecuzione.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="331"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="332"/>
        <location filename="mainwindow.cpp" line="338"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="368"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Seleziona un file ISO da scrivere nell&apos;unità USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="374"/>
        <location filename="mainwindow.cpp" line="442"/>
        <source>Select Source Directory</source>
        <translation>Seleziona la directory sorgente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Impossibile trovare il file %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="395"/>
        <source>Hide advanced options</source>
        <translation>Opzioni avanzate nascoste</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="441"/>
        <location filename="mainwindow.cpp" line="456"/>
        <source>Select Source</source>
        <translation>Seleziona la sorgente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <location filename="mainwindow.cpp" line="462"/>
        <source>Select ISO file</source>
        <translation>Seleziona un file ISO</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Devi eseguire questo programma come utente root</translation>
    </message>
</context>
</TS>

==> live-usb-maker-gui-antix_0.2.17.tar.xz: live-usb-maker-gui-antix/translations/live-usb-maker-gui-antix_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Esci dall&apos;applicazione</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <location filename="mainwindow.cpp" line="462"/>
        <location filename="mainwindow.cpp" line="481"/>
        <source>Select ISO</source>
        <translation>Seleziona un file ISO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="250"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleziona il dispositivo USB di destinazione&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleziona un file ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Opzioni avanzate</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Crea il filesystem ext4, anche se ne esiste già uno</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Salva la directory boot quando si aggiorna una USB-Live</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Usa il partizionamento GPT invece di quello MS-DOS</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>Partizionamento GPT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Aggiorna (solo aggiorna una USB Live esistente)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Non sostituire i file di syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Mantieni i file di syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignora il controllo dei dispositivi rimovibili/USB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Disabilita temporaneamente il montaggio automatico</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Imposta il flag del disco come pmbr_boot (non effettua il boot tramite UEFI)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Non usare fuseiso per il montaggio dei file iso</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Dimensione della partizione ESP (UEFI):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="418"/>
        <source>Verbosity (less to more):</source>
        <translation>Dettagli (da meno a più):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="457"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="462"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="472"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="493"/>
        <source>Make separate data partition (percent)</source>
        <translation>Creare una partizione dati separata (percentuale)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="500"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Refresh drive list</source>
        <translation>Aggiorna l&apos;elenco delle unità</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="524"/>
        <location filename="mainwindow.cpp" line="407"/>
        <source>Show advanced options</source>
        <translation>Mostra le opzioni avanzate</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="544"/>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="559"/>
        <source>Full-featured mode - writable LiveUSB</source>
        <translation>Modalità full-optional - LiveUSB scrivibile</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="569"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Sola lettura, non può essere utilizzato con la persistenza</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="572"/>
        <source>Image mode - read-only LiveUSB (dd)</source>
        <translation>Modalità Immagine - LiveUSB in sola-lettura (dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="586"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Per distro diverse da antiX/MX usa Modalità Immagine (dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="669"/>
        <source>Percent of USB-device to use:</source>
        <translation>Percentuale del dispositivo USB da usare:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="676"/>
        <source>Label ext partition:</source>
        <translation>Etichetta della partizione ext:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="724"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Non eseguire i comandi che hanno effetto sul dispositivo USB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="727"/>
        <source>Dry run (no change to system)</source>
        <translation>Fai una prova (nessuna modifica al sistema)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="734"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Clona da una USB Live montata, o da un file ISO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="737"/>
        <source>Clone an existing live system</source>
        <translation>Clona un sistema &apos;live&apos; esistente</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="744"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Imposta il boot da una partizione crittografata. Verrà richiesta la passphrase al primo avvio</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="747"/>
        <source>Encrypt</source>
        <translation>Crittografa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="754"/>
        <source>Clone running live system</source>
        <translation>Clona il sistema &apos;live&apos; in esecuzione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <location filename="mainwindow.cpp" line="267"/>
        <location filename="mainwindow.cpp" line="392"/>
        <source>Failure</source>
        <translation>Operazione non riuscita</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Sorgente e destinazione sono sullo stesso dispositivo, seleziona di nuovo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="111"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Scrittura di %1 su /dev/%2, utilizzando il comando &apos;dd&apos;,

Attendi fino al completamento del processo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>Success</source>
        <translation>Operazione riuscita</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>LiveUSB creation successful!</source>
        <translation>La creazione della USB Live ha avuto successo!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Riscontrato un errore durante il processo di creazione della USB Live</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Please select a USB device to write to</source>
        <translation>Seleziona un dispositivo USB per la scrittura</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="319"/>
        <location filename="mainwindow.cpp" line="475"/>
        <source>clone</source>
        <translation>clona</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="355"/>
        <source>About %1</source>
        <translation>Circa %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="356"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="357"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programma per la creazione di una USB Live da un file ISO, da un&apos;altra Live USB o da un sistema &apos;live&apos; in esecuzione.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="359"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="368"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Seleziona un file ISO da scrivere nell&apos;unità USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="387"/>
        <location filename="mainwindow.cpp" line="458"/>
        <source>Select Source Directory</source>
        <translation>Seleziona la directory sorgente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="392"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Impossibile trovare il file %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="413"/>
        <source>Hide advanced options</source>
        <translation>Nascondi le opzioni avanzate</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="457"/>
        <location filename="mainwindow.cpp" line="473"/>
        <source>Select Source</source>
        <translation>Seleziona la sorgente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="461"/>
        <location filename="mainwindow.cpp" line="479"/>
        <source>Select ISO file</source>
        <translation>Seleziona un file ISO</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="32"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="about.cpp" line="33"/>
        <location filename="about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="main.cpp" line="75"/>
        <source>You must run this program as root.</source>
        <translation>Devi eseguire questo programma come utente root</translation>
    </message>
</context>
</TS>
